package com.example.matuletest.ui.auth

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.matuletest.domain.AuthUseCase
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch

class AuthScreenViewModel: ViewModel() {
     val authScreenState = MutableStateFlow(AuthScreenState())
     val registrationScreenState = MutableStateFlow(RegistrationScreenState())
     val useCase = AuthUseCase()
    fun setPassword(password: String, isRegistration: Boolean = false){
        viewModelScope.launch {
            if (isRegistration) {
                registrationScreenState.update {
                    it.copy(password = password)
                }
            } else {
                authScreenState.update {
                    it.copy(password = password)
                }
            }
        }
    }

    fun setEmail(email: String, isRegistration: Boolean = false){
        viewModelScope.launch {
            if (isRegistration) {
                registrationScreenState.update {
                    it.copy(email = email)
                }
            } else {
                authScreenState.update {
                    it.copy(email = email)
                }
            }
        }
    }

    fun auth(){
        viewModelScope.launch {
            useCase.auth(
                authScreenState.value.email,
                authScreenState.value.password
            ).collect{ result ->
                    if(result) authScreenState.update { it.copy(isSignIn = true) }
                }
        }
    }

    fun reg(){
        viewModelScope.launch {
            useCase.registration(
                registrationScreenState.value.email,
                registrationScreenState.value.password
            ).collect{ result ->
                if(result) registrationScreenState.update { it.copy(isSignUp = true) }
            }
        }
    }
}