package com.example.matuletest.ui.auth.screens

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.text.ClickableText
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import com.example.matuletest.ui.auth.AuthScreenViewModel

@Composable
fun RegistrationScreen(navController: NavController) {
    val viewModel: AuthScreenViewModel = viewModel()
    RegistrationContent(viewModel, navController)
}

@Composable
fun RegistrationContent(viewModel: AuthScreenViewModel, navController: NavController){
    val regState = viewModel.registrationScreenState.collectAsState()

    if (regState.value.isSignUp) {
        Text("Success Registration")
    }

    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {
        Text(
            text = "Регистрация!",
            style = TextStyle(fontSize = 32.sp, fontWeight = FontWeight.Bold),
            modifier = Modifier.height(60.dp).padding(bottom = 20.dp)
        )

        Text(
            text = "Заполните Свои данные или продолжите через социальные медиа",
            modifier = Modifier
                .fillMaxWidth()
                .padding(bottom = 20.dp),
            style = TextStyle(fontSize = 16.sp),
            textAlign = TextAlign.Center,
            maxLines = 2
        )

//        Text(text = "Ваше имя", modifier = Modifier.padding(end = 255.dp))
//        TextField(
//            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
//            value = regState.value.email,
//            onValueChange = {
//                viewModel.setEmail(it)
//            })

        Text(text = "Email", modifier = Modifier.padding(end = 255.dp))
        TextField(
            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
            value = regState.value.email,
            onValueChange = {
                viewModel.setEmail(it, true)
            })

        Text(text = "Password", modifier = Modifier.padding(end = 225.dp))
        TextField(
            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
            value = regState.value.password,
            onValueChange = {
                viewModel.setPassword(it, true)
            },
            visualTransformation = PasswordVisualTransformation()
        )

        Button(
            modifier = Modifier.width(350.dp).height(50.dp),
            colors = androidx.compose.material3.ButtonDefaults.buttonColors(
                containerColor = Color(0xFF48B2E7),
                contentColor = Color.White
            ),
            onClick = {
                viewModel.reg()
            }) {
            Text("Зарегестрироваться")
        }

        Row(
            modifier = Modifier
                .padding(top = 16.dp)
                .fillMaxWidth(),
            horizontalArrangement = Arrangement.Center
        ) {
            Text(
                text = "Есть аккаунт? ",
                style = TextStyle(fontSize = 16.sp, color = Color.Black)
            )

            ClickableText(
                text = buildAnnotatedString { append("Войти") },
                onClick = {
                    navController.navigate("auth_screen")
                },
                style = TextStyle(
                    fontSize = 16.sp,
                    color = Color.Black
                ),
            )
        }
    }
}